@@ -1,5 +1,5 @@
-require 'rubygems'
 require 'benchmark'
+$LOAD_PATH.unshift 'lib'
 
 RUNS = 50_0000
 DEFAULTS = {:memory=>0}
@@ -35,8 +35,12 @@ end
 
 def memory
   pid = Process.pid
-  map = `pmap -d #{pid}`
+  if RUBY_PLATFORM.downcase.include?("darwin")
+    map = `vmmap #{pid}`
+  else
+    map = `pmap -d #{pid}`
+  end
   map.split("\n").last.strip.squeeze(' ').split(' ')[3].to_i - DEFAULTS[:memory]
 end
 
-DEFAULTS[:memory] = memory + 4 #4 => 0 for base calls
\ No newline at end of file
+DEFAULTS[:memory] = memory + 4 #4 => 0 for base calls
