@@ -1,5 +1,5 @@
-require 'benchmark/base'
+require_relative 'base'
 
 puts "Baseline: (doing nothing in a loop)"
 results_test{true}
-puts ""
\ No newline at end of file
+puts ""
