@@ -1,7 +1,6 @@
 require 'spec_helper'
 require 'active_record'
 require 'fast_gettext/translation_repository/db'
-require 'support/be_accessible_matcher'
 
 FastGettext::TranslationRepository::Db.require_models
 
@@ -84,28 +83,6 @@ describe FastGettext::TranslationRepository::Db do
     }.should change{ TranslationKey.count }.by(-1)
   end
 
-  it "model attributes should be accessible" do
-    key = TranslationKey.new(:key => 'New Key', :translations_attributes => { '0' => {:text => 'New Key En', :locale => 'en'}})
-
-    key.key.should == 'New Key'
-
-    key.should be_accessible(:key)
-    key.should be_accessible(:translations)
-    key.should be_accessible(:translations_attributes)
-    key.should_not be_accessible(:created_at)
-
-    translation = key.translations.first
-
-    translation.text.should == 'New Key En'
-    translation.locale.should == 'en'
-
-    translation.should be_accessible(:locale)
-    translation.should be_accessible(:text)
-    translation.should be_accessible(:translation_key)
-    translation.should be_accessible(:translation_key_id)
-    translation.should_not be_accessible(:created_at)
-  end
-
   it "expires the cache when updated" do
     FastGettext.should_receive(:expire_cache_for).with('car')
     translation_text = create_translation 'car', 'Auto'
